@@ -114,7 +114,7 @@ class SettingsMenu(QtWidgets.QToolButton):
         menu.addSeparator()
         self._add_title(menu, "Application")
         self._add_application_section(menu)
-        menu.triggered.connect(self._on_item_click)  # pylint: disable=no-member
+        menu.triggered.connect(self._on_item_click)
 
         self.setMenu(menu)
 
@@ -217,7 +217,7 @@ class SettingsMenu(QtWidgets.QToolButton):
             action.setChecked(language in self.settings.value("language"))
             language_menu.addAction(action)
 
-        if system_info.is_prebuild_package():
+        if system_info.is_prebuild_package() or system_info.is_flatpak_package():
             action = QtGui.QAction("... open data folder", menu)
             traineddata_path = system_info.config_directory() / "tessdata"
             action.setObjectName(f"file:///{traineddata_path.resolve()}")
