@@ -20,8 +20,6 @@ from normcap.screengrab import grab_screens
 
 logger = logging.getLogger(__name__)
 
-# TODO: Remove pylint disable no-member when https://github.com/PyCQA/pylint/issues/5378
-
 
 class Communicate(QtCore.QObject):
     """TrayMenus' communication bus."""
@@ -65,13 +63,28 @@ class SystemTray(QtWidgets.QSystemTrayIcon):
 
         self.screens: dict[int, Screen] = system_info.screens()
 
-        self.setIcon(utils.get_icon("tray.png", "tool-magic-symbolic"))
+        self._set_tray_icon()
         self._add_tray_menu()
         self._add_update_checker()
         self._add_notifier()
         self._set_signals()
         self._update_screenshots()
 
+    def _set_tray_icon(self):
+        self.setIcon(utils.get_icon("tray.png", "tool-magic-symbolic"))
+
+    def _color_tray_icon(self):
+        if sizes := self.icon().availableSizes():
+            pixmap = self.icon().pixmap(sizes[-1])
+            mask = pixmap.createMaskFromColor(
+                QtGui.QColor("transparent"), QtCore.Qt.MaskInColor
+            )
+            pixmap.fill(QtGui.QColor(str(self.settings.value("color"))))
+            pixmap.setMask(mask)
+            self.setIcon(QtGui.QIcon(pixmap))
+
+            QtCore.QTimer.singleShot(5000, self._set_tray_icon)
+
     def _set_signals(self):
         """Set up signals to trigger program logic."""
         self.com.on_tray_menu_capture.connect(self._delayed_update_screenshots)
@@ -82,6 +95,7 @@ class SystemTray(QtWidgets.QSystemTrayIcon):
         self.com.on_image_cropped.connect(self._capture_to_ocr)
         self.com.on_ocr_performed.connect(self._copy_to_clipboard)
         self.com.on_copied_to_clipboard.connect(self._notify_or_close)
+        self.com.on_copied_to_clipboard.connect(self._color_tray_icon)
 
         self.com.on_minimize_windows.connect(self._close_windows)
         self.com.on_set_cursor_wait.connect(
@@ -131,13 +145,11 @@ class SystemTray(QtWidgets.QSystemTrayIcon):
         menu = QtWidgets.QMenu()
 
         action = QtGui.QAction("Capture", menu)
-        action.triggered.connect(  # pylint: disable=no-member
-            self.com.on_tray_menu_capture.emit
-        )
+        action.triggered.connect(self.com.on_tray_menu_capture.emit)
         menu.addAction(action)
 
         action = QtGui.QAction("Exit", menu)
-        action.triggered.connect(self.com.on_quit.emit)  # pylint: disable=no-member
+        action.triggered.connect(self.com.on_quit.emit)
         menu.addAction(action)
 
         self.setContextMenu(menu)
@@ -152,6 +164,7 @@ class SystemTray(QtWidgets.QSystemTrayIcon):
             DesktopEnvironment.GNOME,
             DesktopEnvironment.KDE,
         ]:
+            self.com.on_window_positioned.connect(self._create_next_window)
             self._create_next_window()
 
     def _create_next_window(self):
