@@ -38,7 +38,7 @@ def configure_tesseract_binary():
         pytesseract.pytesseract.get_tesseract_version = _patched_get_tesseract_version
 
 
-@functools.lru_cache()
+@functools.lru_cache
 def get_tesseract_languages(tessdata_path) -> list[str]:
     """Get info abput tesseract setup."""
     configure_tesseract_binary()
@@ -58,13 +58,13 @@ def get_tesseract_languages(tessdata_path) -> list[str]:
         raise ValueError(
             "Could not load any languages for tesseract. "
             + "On Windows, make sure that TESSDATA_PREFIX environment variable is set. "
-            + "On Linux/MacOS see if 'tesseract --list-langs' work is the command line."
+            + "On Linux/macOS see if 'tesseract --list-langs' work is the command line."
         )
 
     return languages
 
 
-@functools.lru_cache()
+@functools.lru_cache
 def get_tesseract_version() -> version.Version:
     """Get info abput tesseract setup."""
     tesseract_version = str(pytesseract.get_tesseract_version()).splitlines()[0]
