@@ -41,7 +41,7 @@ def split_full_desktop_to_screens(full_image: QtGui.QImage) -> list[QtGui.QImage
     return images
 
 
-def display_manager_is_wayland() -> bool:
+def _display_manager_is_wayland() -> bool:
     """Identify relevant display managers (Linux)."""
     if sys.platform != "linux":
         return False
@@ -58,8 +58,8 @@ def _get_gnome_version_xml() -> str:
     raise FileNotFoundError
 
 
-@functools.lru_cache()
-def gnome_shell_version() -> Optional[version.Version]:
+@functools.lru_cache
+def get_gnome_version() -> Optional[version.Version]:
     """Get gnome-shell version (Linux, Gnome)."""
     if sys.platform != "linux":
         return None
@@ -71,44 +71,58 @@ def gnome_shell_version() -> Optional[version.Version]:
     ):
         return None
 
-    shell_version = _parse_gnome_version_from_xml()
-    if not shell_version:
-        shell_version = _parse_gnome_version_from_shell_cmd()
-
-    return shell_version
+    return _parse_gnome_version_from_xml() or _parse_gnome_version_from_shell_cmd()
 
 
 def _parse_gnome_version_from_xml():
     """Try parsing gnome-version xml file."""
-    shell_version = None
+    gnome_version = None
     try:
         content = _get_gnome_version_xml()
         if result := re.search(r"(?<=<platform>)\d+(?=<\/platform>)", content):
-            platform = int(result.group(0))
+            platform = int(result[0])
         else:
             raise ValueError
         if result := re.search(r"(?<=<minor>)\d+(?=<\/minor>)", content):
-            minor = int(result.group(0))
+            minor = int(result[0])
         else:
             raise ValueError
-        shell_version = version.parse(f"{platform}.{minor}")
+        gnome_version = version.parse(f"{platform}.{minor}")
     except Exception as e:  # pylint: disable=broad-except
-        logger.error("Exception when trying to get gnome-shell version %s", e)
+        logger.warning("Exception when trying to get gnome version from xml %s", e)
 
-    return shell_version
+    return gnome_version
 
 
 def _parse_gnome_version_from_shell_cmd():
     """Try parsing gnome-shell output."""
-    shell_version = None
+    gnome_version = None
     try:
         output_raw = subprocess.check_output(["gnome-shell", "--version"], shell=False)
         output = output_raw.decode().strip()
         if result := re.search(r"\s+([\d.]+)", output):
-            shell_version = version.parse(result.groups()[0])
+            gnome_version = version.parse(result.groups()[0])
     except (subprocess.CalledProcessError, FileNotFoundError):
         pass
     except Exception as e:  # pylint: disable=broad-except
-        logger.error("Exception when trying to get gnome-shell version %s", e)
+        logger.warning("Exception when trying to get gnome version from cli %s", e)
 
-    return shell_version
+    return gnome_version
+
+
+# pylint: disable=C0415 # Import outside toplevel
+def get_appropriate_grab_screens():
+    if not _display_manager_is_wayland():
+        from normcap.screengrab import qt
+
+        return qt.grab_screens
+
+    gnome_version = get_gnome_version()
+    if not gnome_version or gnome_version >= version.parse("41"):
+        from normcap.screengrab import dbus_portal
+
+        return dbus_portal.grab_screens
+
+    from normcap.screengrab import dbus_shell
+
+    return dbus_shell.grab_screens
